@@ -1,9 +1,9 @@
 from typing import List, Union
 import requests, json
-from ddd_objects.infrastructure.ao import exception_class_dec
 from ddd_objects.infrastructure.repository_impl import error_factory
 from ddd_objects.domain.exception import return_codes
 from .do import (
+    DeploymentSettingDO,
     ReleaseNodeInfoDO,
     ConditionDO,
     ConfigMapDO,
@@ -142,7 +142,7 @@ class K3SController:
         config_map_user_settings: List[ConfigMapUserSettingDO],
         timeout=10
     ):
-        data = [setting.to_json() for setting in config_map_user_settings]
+        data = [setting.dict() for setting in config_map_user_settings]
         data = json.dumps(data)
         response=requests.post(
             f'{self.url}/config_maps', 
@@ -214,6 +214,15 @@ class K3SController:
         infos = json.loads(response.text)
         self._check_error(response.status_code, infos)
         return [JobDO(**s) for s in infos]
+
+    def create_deployment(self, deployment_setting: DeploymentSettingDO, timeout=10):
+        data = json.dumps(deployment_setting.dict())
+        response=requests.post(
+            f'{self.url}/deployment', 
+            headers=self.header, data=data, timeout=timeout)
+        info = json.loads(response.text)
+        self._check_error(response.status_code, info)
+        return DeploymentDO(**info)
         
     def create_job(self, job_setting:JobSettingDO, timeout=10):
         data = json.dumps(job_setting.dict())
@@ -229,7 +238,7 @@ class K3SController:
         pod_log_setting: PodLogSettingDO,
         timeout:int=10
     ):
-        data = json.dumps(pod_log_setting.to_json())
+        data = json.dumps(pod_log_setting.dict())
         response=requests.get(
             f'{self.url}/log', 
             headers=self.header, data=data,timeout=timeout)
@@ -237,6 +246,20 @@ class K3SController:
         self._check_error(response.status_code, info)
         return info
 
+
+    def delete_deployment(
+        self,
+        namespace_name:str,
+        deployment_name:str,
+        timeout:int=10
+    ):
+        response=requests.delete(
+            f'{self.url}/deployment/namespace_name/{namespace_name}/deployment_name/{deployment_name}', 
+            headers=self.header, timeout=timeout)
+        info = json.loads(response.text)
+        self._check_error(response.status_code, info)
+        return info
+
     def delete_job(
         self,
         namespace_name:str,
